@@ -1,6 +1,7 @@
 /* { dg-do run { target m68k-*-* sparc-*-* } } */
-/* { dg-options { -m68000 -O2 } { target m68k-*-* } } */
-/* { dg-options { -O2 } { target sparc-*-* } } */
+/* { dg-options { -O2 } } */
+
+extern void abort (void);
 
 typedef float SFtype __attribute__ ((mode (SF)));
 typedef float DFtype __attribute__ ((mode (DF)));
